class _AppDomain:
 """ Exposes the public members of the System.AppDomain class to unmanaged code. """
 def AppendPrivatePath(self,path):
  """
  AppendPrivatePath(self: _AppDomain,path: str)

   Provides COM objects with version-independent access to the 

    System.AppDomain.AppendPrivatePath(System.String) method.

  

  

   path: The name of the directory to be appended to the private path.
  """
  pass
 def ClearPrivatePath(self):
  """
  ClearPrivatePath(self: _AppDomain)

   Provides COM objects with version-independent access to the System.AppDomain.ClearPrivatePath 

    method.
  """
  pass
 def ClearShadowCopyPath(self):
  """
  ClearShadowCopyPath(self: _AppDomain)

   Provides COM objects with version-independent access to the System.AppDomain.ClearShadowCopyPath 

    method.
  """
  pass
 def CreateInstance(self,assemblyName,typeName,*__args):
  """
  CreateInstance(self: _AppDomain,assemblyName: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityAttributes: Evidence) -> ObjectHandle

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.CreateInstance(System.String,System.String,System.Boolean,System.Reflection.Bind

    ingFlags,System.Reflection.Binder,System.Object[],System.Globalization.CultureInfo,System.Object[

    ],System.Security.Policy.Evidence) method overload.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects using reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityAttributes: Information used to authorize creation of typeName.

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.

  

  CreateInstance(self: _AppDomain,assemblyName: str,typeName: str,activationAttributes: Array[object]) -> ObjectHandle

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.CreateInstance(System.String,System.String,System.Object[]) method overload.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.

  

  CreateInstance(self: _AppDomain,assemblyName: str,typeName: str) -> ObjectHandle

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.CreateInstance(System.String,System.String) method.

  

  

   assemblyName: The display name of the assembly. See System.Reflection.Assembly.FullName.

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   Returns: An object that is a wrapper for the new instance specified by typeName. The return value needs 

    to be unwrapped to access the real object.
  """
  pass
 def CreateInstanceFrom(self,assemblyFile,typeName,*__args):
  """
  CreateInstanceFrom(self: _AppDomain,assemblyFile: str,typeName: str,ignoreCase: bool,bindingAttr: BindingFlags,binder: Binder,args: Array[object],culture: CultureInfo,activationAttributes: Array[object],securityAttributes: Evidence) -> ObjectHandle

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.CreateInstanceFrom(System.String,System.String,System.Boolean,System.Reflection.

    BindingFlags,System.Reflection.Binder,System.Object[],System.Globalization.CultureInfo,System.Obj

    ect[],System.Security.Policy.Evidence) method overload.

  

  

   assemblyFile: The name,including the path,of a file that contains an assembly that defines the requested 

    type. The assembly is loaded using the System.Reflection.Assembly.LoadFrom(System.String)  

    method.

  

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   ignoreCase: A Boolean value specifying whether to perform a case-sensitive search or not.

   bindingAttr: A combination of zero or more bit flags that affect the search for the typeName constructor. If 

    bindingAttr is zero,a case-sensitive search for public constructors is conducted.

  

   binder: An object that enables the binding,coercion of argument types,invocation of members,and 

    retrieval of System.Reflection.MemberInfo objects through reflection. If binder is null,the 

    default binder is used.

  

   args: The arguments to pass to the constructor. This array of arguments must match in number,order,

    and type the parameters of the constructor to invoke. If the default constructor is preferred,

    args must be an empty array or null.

  

   culture: Culture-specific information that governs the coercion of args to the formal types declared for 

    the typeName constructor. If culture is null,the System.Globalization.CultureInfo for the 

    current thread is used.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   securityAttributes: Information used to authorize creation of typeName.

   Returns: An object that is a wrapper for the new instance,or null if typeName is not found. The return 

    value needs to be unwrapped to access the real object.

  

  CreateInstanceFrom(self: _AppDomain,assemblyFile: str,typeName: str,activationAttributes: Array[object]) -> ObjectHandle

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.CreateInstanceFrom(System.String,System.String,System.Object[]) method 

    overload.

  

  

   assemblyFile: The name,including the path,of a file that contains an assembly that defines the requested 

    type. The assembly is loaded using the System.Reflection.Assembly.LoadFrom(System.String)  

    method.

  

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   activationAttributes: An array of one or more attributes that can participate in activation. Typically,an array that 

    contains a single System.Runtime.Remoting.Activation.UrlAttribute object. The 

    System.Runtime.Remoting.Activation.UrlAttribute specifies the URL that is required to activate a 

    remote object.

  

   Returns: An object that is a wrapper for the new instance,or null if typeName is not found. The return 

    value needs to be unwrapped to access the real object.

  

  CreateInstanceFrom(self: _AppDomain,assemblyFile: str,typeName: str) -> ObjectHandle

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.CreateInstanceFrom(System.String,System.String) method overload.

  

  

   assemblyFile: The name,including the path,of a file that contains an assembly that defines the requested 

    type. The assembly is loaded using the System.Reflection.Assembly.LoadFrom(System.String)  

    method.

  

   typeName: The fully qualified name of the requested type,including the namespace but not the assembly,as 

    returned by the System.Type.FullName property.

  

   Returns: An object that is a wrapper for the new instance,or null if typeName is not found. The return 

    value needs to be unwrapped to access the real object.
  """
  pass
 def DefineDynamicAssembly(self,name,access,*__args):
  """
  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,evidence: Evidence,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess,System.Security.Policy.Evidence,System.Security.PermissionSet,System.Security.P

    ermissionSet,System.Security.PermissionSet) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   Returns: Represents the dynamic assembly created.

  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess,System.String,System.Security.PermissionSet,System.Security.PermissionSet,Syste

    m.Security.PermissionSet) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the assembly will be saved. If dir is null,the directory 

    defaults to the current directory.

  

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   Returns: Represents the dynamic assembly created.

  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,evidence: Evidence,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet,isSynchronized: bool) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess,System.String,System.Security.Policy.Evidence,System.Security.PermissionSet,Sys

    tem.Security.PermissionSet,System.Security.PermissionSet,System.Boolean) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the dynamic assembly will be saved. If dir is null,the 

    directory defaults to the current directory.

  

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   isSynchronized: true to synchronize the creation of modules,types,and members in the dynamic assembly; 

    otherwise,false.

  

   Returns: Represents the dynamic assembly created.

  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,evidence: Evidence,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess,System.String,System.Security.Policy.Evidence,System.Security.PermissionSet,Sys

    tem.Security.PermissionSet,System.Security.PermissionSet) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the assembly will be saved. If dir is null,the directory 

    defaults to the current directory.

  

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   Returns: Represents the dynamic assembly created.

  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str,evidence: Evidence) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess,System.String,System.Security.Policy.Evidence) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the assembly will be saved. If dir is null,the directory 

    defaults to the current directory.

  

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   Returns: Represents the dynamic assembly created.

  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,dir: str) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess,System.String) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   dir: The name of the directory where the assembly will be saved. If dir is null,the directory 

    defaults to the current directory.

  

   Returns: Represents the dynamic assembly created.

  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The access mode for the dynamic assembly.

   Returns: Represents the dynamic assembly created.

  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,requiredPermissions: PermissionSet,optionalPermissions: PermissionSet,refusedPermissions: PermissionSet) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess,System.Security.PermissionSet,System.Security.PermissionSet,System.Security.Per

    missionSet) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   requiredPermissions: The required permissions request.

   optionalPermissions: The optional permissions request.

   refusedPermissions: The refused permissions request.

   Returns: Represents the dynamic assembly created.

  DefineDynamicAssembly(self: _AppDomain,name: AssemblyName,access: AssemblyBuilderAccess,evidence: Evidence) -> AssemblyBuilder

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.DefineDynamicAssembly(System.Reflection.AssemblyName,System.Reflection.Emit.Asse

    mblyBuilderAccess,System.Security.Policy.Evidence) method overload.

  

  

   name: The unique identity of the dynamic assembly.

   access: The mode in which the dynamic assembly will be accessed.

   evidence: The evidence supplied for the dynamic assembly. The evidence is used unaltered as the final set 

    of evidence used for policy resolution.

  

   Returns: Represents the dynamic assembly created.
  """
  pass
 def DoCallBack(self,theDelegate):
  """
  DoCallBack(self: _AppDomain,theDelegate: CrossAppDomainDelegate)

   Provides COM objects with version-independent access to the 

    System.AppDomain.DoCallBack(System.CrossAppDomainDelegate) method.

  

  

   theDelegate: A delegate that specifies a method to call.
  """
  pass
 def Equals(self,other):
  """
  Equals(self: _AppDomain,other: object) -> bool

  

   Provides COM objects with version-independent access to the inherited 

    System.Object.Equals(System.Object) method.

  

  

   other: The System.Object to compare to the current System.Object.

   Returns: true if the specified System.Object is equal to the current System.Object; otherwise,false.
  """
  pass
 def ExecuteAssembly(self,assemblyFile,assemblySecurity=None,args=None):
  """
  ExecuteAssembly(self: _AppDomain,assemblyFile: str,assemblySecurity: Evidence,args: Array[str]) -> int

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.ExecuteAssembly(System.String,System.Security.Policy.Evidence,System.String[]) 

    method overload.

  

  

   assemblyFile: The name of the file that contains the assembly to execute.

   assemblySecurity: The supplied evidence for the assembly.

   args: The arguments to the entry point of the assembly.

   Returns: The value returned by the entry point of the assembly.

  ExecuteAssembly(self: _AppDomain,assemblyFile: str) -> int

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.ExecuteAssembly(System.String) method overload.

  

  

   assemblyFile: The name of the file that contains the assembly to execute.

   Returns: The value returned by the entry point of the assembly.

  ExecuteAssembly(self: _AppDomain,assemblyFile: str,assemblySecurity: Evidence) -> int

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.ExecuteAssembly(System.String,System.Security.Policy.Evidence) method overload.

  

  

   assemblyFile: The name of the file that contains the assembly to execute.

   assemblySecurity: Evidence for loading the assembly.

   Returns: The value returned by the entry point of the assembly.
  """
  pass
 def GetAssemblies(self):
  """
  GetAssemblies(self: _AppDomain) -> Array[Assembly]

  

   Provides COM objects with version-independent access to the System.AppDomain.GetAssemblies 

    method.

  

   Returns: An array of assemblies in this application domain.
  """
  pass
 def GetData(self,name):
  """
  GetData(self: _AppDomain,name: str) -> object

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.GetData(System.String) method.

  

  

   name: The name of a predefined application domain property,or the name of an application domain 

    property you have defined.

  

   Returns: The value of the name property.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: _AppDomain) -> int

  

   Provides COM objects with version-independent access to the inherited System.Object.GetHashCode 

    method.

  

   Returns: A hash code for the current System.Object.
  """
  pass
 def GetIDsOfNames(self,riid,rgszNames,cNames,lcid,rgDispId):
  """
  GetIDsOfNames(self: _AppDomain,riid: Guid,rgszNames: IntPtr,cNames: UInt32,lcid: UInt32,rgDispId: IntPtr) -> Guid

  

   Maps a set of names to a corresponding set of dispatch identifiers.

  

   riid: Reserved for future use. Must be IID_NULL.

   rgszNames: Passed-in array of names to be mapped.

   cNames: Count of the names to be mapped.

   lcid: The locale context in which to interpret the names.

   rgDispId: Caller-allocated array which receives the IDs corresponding to the names.
  """
  pass
 def GetLifetimeService(self):
  """
  GetLifetimeService(self: _AppDomain) -> object

  

   Provides COM objects with version-independent access to the inherited 

    System.MarshalByRefObject.GetLifetimeService method.

  

   Returns: An object of type System.Runtime.Remoting.Lifetime.ILease used to control the lifetime policy 

    for this instance.
  """
  pass
 def GetType(self):
  """
  GetType(self: _AppDomain) -> Type

  

   Provides COM objects with version-independent access to the System.AppDomain.GetType method.

   Returns: A System.Type representing the type of the current instance.
  """
  pass
 def GetTypeInfo(self,iTInfo,lcid,ppTInfo):
  """
  GetTypeInfo(self: _AppDomain,iTInfo: UInt32,lcid: UInt32,ppTInfo: IntPtr)

   Retrieves the type information for an object,which can then be used to get the type information 

    for an interface.

  

  

   iTInfo: The type information to return.

   lcid: The locale identifier for the type information.

   ppTInfo: Receives a pointer to the requested type information object.
  """
  pass
 def GetTypeInfoCount(self,pcTInfo):
  """
  GetTypeInfoCount(self: _AppDomain) -> UInt32

  

   Retrieves the number of type information interfaces that an object provides (either 0 or 1).
  """
  pass
 def InitializeLifetimeService(self):
  """
  InitializeLifetimeService(self: _AppDomain) -> object

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.InitializeLifetimeService method.

  

   Returns: Always null.
  """
  pass
 def Invoke(self,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr):
  """
  Invoke(self: _AppDomain,dispIdMember: UInt32,riid: Guid,lcid: UInt32,wFlags: Int16,pDispParams: IntPtr,pVarResult: IntPtr,pExcepInfo: IntPtr,puArgErr: IntPtr) -> Guid

  

   Provides access to properties and methods exposed by an object.

  

   dispIdMember: Identifies the member.

   riid: Reserved for future use. Must be IID_NULL.

   lcid: The locale context in which to interpret arguments.

   wFlags: Flags describing the context of the call.

   pDispParams: Pointer to a structure containing an array of arguments,an array of argument DISPIDs for named 

    arguments,and counts for the number of elements in the arrays.

  

   pVarResult: Pointer to the location where the result is to be stored.

   pExcepInfo: Pointer to a structure that contains exception information.

   puArgErr: The index of the first argument that has an error.
  """
  pass
 def Load(self,*__args):
  """
  Load(self: _AppDomain,rawAssembly: Array[Byte],rawSymbolStore: Array[Byte],securityEvidence: Evidence) -> Assembly

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.Load(System.Byte[],System.Byte[],System.Security.Policy.Evidence) method 

    overload.

  

  

   rawAssembly: An array of type byte that is a COFF-based image containing an emitted assembly.

   rawSymbolStore: An array of type byte containing the raw bytes representing the symbols for the assembly.

   securityEvidence: Evidence for loading the assembly.

   Returns: The loaded assembly.

  Load(self: _AppDomain,assemblyRef: AssemblyName,assemblySecurity: Evidence) -> Assembly

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.Load(System.Reflection.AssemblyName,System.Security.Policy.Evidence) method 

    overload.

  

  

   assemblyRef: An object that describes the assembly to load.

   assemblySecurity: Evidence for loading the assembly.

   Returns: The loaded assembly.

  Load(self: _AppDomain,assemblyString: str,assemblySecurity: Evidence) -> Assembly

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.Load(System.String,System.Security.Policy.Evidence) method overload.

  

  

   assemblyString: The display name of the assembly. See System.Reflection.Assembly.FullName.

   assemblySecurity: Evidence for loading the assembly.

   Returns: The loaded assembly.

  Load(self: _AppDomain,rawAssembly: Array[Byte],rawSymbolStore: Array[Byte]) -> Assembly

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.Load(System.Byte[],System.Byte[]) method overload.

  

  

   rawAssembly: An array of type byte that is a COFF-based image containing an emitted assembly.

   rawSymbolStore: An array of type byte containing the raw bytes representing the symbols for the assembly.

   Returns: The loaded assembly.

  Load(self: _AppDomain,assemblyRef: AssemblyName) -> Assembly

  

   Provides COM objects with version-independent access to the 

    System.AppDomain.Load(System.Reflection.AssemblyName) method overload.

  

  

   assemblyRef: An object that describes the assembly to load.

   Returns: The loaded assembly.

  Load(self: _AppDomain,assemblyString: str) -> Assembly

  

   Provides COM objects with version-independent access to the System.AppDomain.Load(System.String) 

    method overload.

  

  

   assemblyString: The display name of the assembly. See System.Reflection.Assembly.FullName.

   Returns: The loaded assembly.

  Load(self: _AppDomain,rawAssembly: Array[Byte]) -> Assembly

  

   Provides COM objects with version-independent access to the System.AppDomain.Load(System.Byte[]) 

    method overload.

  

  

   rawAssembly: An array of type byte that is a COFF-based image containing an emitted assembly.

   Returns: The loaded assembly.
  """
  pass
 def SetAppDomainPolicy(self,domainPolicy):
  """
  SetAppDomainPolicy(self: _AppDomain,domainPolicy: PolicyLevel)

   Provides COM objects with version-independent access to the 

    System.AppDomain.SetAppDomainPolicy(System.Security.Policy.PolicyLevel) method.

  

  

   domainPolicy: The security policy level.
  """
  pass
 def SetCachePath(self,s):
  """
  SetCachePath(self: _AppDomain,s: str)

   Provides COM objects with version-independent access to the 

    System.AppDomain.SetCachePath(System.String) method.

  

  

   s: The fully qualified path to the shadow copy location.
  """
  pass
 def SetData(self,name,data):
  """
  SetData(self: _AppDomain,name: str,data: object)

   Provides COM objects with version-independent access to the 

    System.AppDomain.SetData(System.String,System.Object) method.

  

  

   name: The name of a user-defined application domain property to create or change.

   data: The value of the property.
  """
  pass
 def SetPrincipalPolicy(self,policy):
  """
  SetPrincipalPolicy(self: _AppDomain,policy: PrincipalPolicy)

   Provides COM objects with version-independent access to the 

    System.AppDomain.SetPrincipalPolicy(System.Security.Principal.PrincipalPolicy) method.

  

  

   policy: One of the System.Security.Principal.PrincipalPolicy values that specifies the type of the 

    principal object to attach to threads.
  """
  pass
 def SetShadowCopyPath(self,s):
  """
  SetShadowCopyPath(self: _AppDomain,s: str)

   Provides COM objects with version-independent access to the 

    System.AppDomain.SetShadowCopyPath(System.String) method.

  

  

   s: A list of directory names,where each name is separated by a semicolon.
  """
  pass
 def SetThreadPrincipal(self,principal):
  """
  SetThreadPrincipal(self: _AppDomain,principal: IPrincipal)

   Provides COM objects with version-independent access to the 

    System.AppDomain.SetThreadPrincipal(System.Security.Principal.IPrincipal) method.

  

  

   principal: The principal object to attach to threads.
  """
  pass
 def ToString(self):
  """
  ToString(self: _AppDomain) -> str

  

   Provides COM objects with version-independent access to the System.AppDomain.ToString method.

   Returns: A string formed by concatenating the literal string "Name:",the friendly name of the 

    application domain,and either string representations of the context policies or the string 

    "There are no context policies."
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 BaseDirectory=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.AppDomain.BaseDirectory property.



Get: BaseDirectory(self: _AppDomain) -> str



"""

 DynamicDirectory=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.AppDomain.DynamicDirectory property.



Get: DynamicDirectory(self: _AppDomain) -> str



"""

 Evidence=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.AppDomain.Evidence property.



Get: Evidence(self: _AppDomain) -> Evidence



"""

 FriendlyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.AppDomain.FriendlyName property.



Get: FriendlyName(self: _AppDomain) -> str



"""

 RelativeSearchPath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.AppDomain.RelativeSearchPath property.



Get: RelativeSearchPath(self: _AppDomain) -> str



"""

 ShadowCopyFiles=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.AppDomain.ShadowCopyFiles property.



Get: ShadowCopyFiles(self: _AppDomain) -> bool



"""


 AssemblyLoad=None
 AssemblyResolve=None
 DomainUnload=None
 ProcessExit=None
 ResourceResolve=None
 TypeResolve=None
 UnhandledException=None




class Cursors(object):
 """ Provides a collection of System.Windows.Forms.Cursor objects for use by a Windows Forms application. """
 AppStarting=None
 Arrow=None
 Cross=None
 Default=None
 Hand=None
 Help=None
 HSplit=None
 IBeam=None
 No=None
 NoMove2D=None
 NoMoveHoriz=None
 NoMoveVert=None
 PanEast=None
 PanNE=None
 PanNorth=None
 PanNW=None
 PanSE=None
 PanSouth=None
 PanSW=None
 PanWest=None
 SizeAll=None
 SizeNESW=None
 SizeNS=None
 SizeNWSE=None
 SizeWE=None
 UpArrow=None
 VSplit=None
 WaitCursor=None




class DataGridViewColumnDesignTimeVisibleAttribute(Attribute,_Attribute):
 """
 Specifies whether a column type is visible in the System.Windows.Forms.DataGridView designer. This class cannot be inherited.

 

 DataGridViewColumnDesignTimeVisibleAttribute(visible: bool)

 DataGridViewColumnDesignTimeVisibleAttribute()
 """
 def Equals(self,obj):
  """
  Equals(self: DataGridViewColumnDesignTimeVisibleAttribute,obj: object) -> bool

  

   Gets a value indicating whether this object is equivalent to the specified object.

  

   obj: The System.Object to compare with the current System.Object.

   Returns: true to indicate that the specified object is a 

    System.Windows.Forms.DataGridViewColumnDesignTimeVisibleAttribute instance with the same 

    System.Windows.Forms.DataGridViewColumnDesignTimeVisibleAttribute.Visible property value as this 

    instance; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DataGridViewColumnDesignTimeVisibleAttribute) -> int

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: DataGridViewColumnDesignTimeVisibleAttribute) -> bool

  

   Gets a value indicating whether this attribute instance is equal to the 

    System.Windows.Forms.DataGridViewColumnDesignTimeVisibleAttribute.Default attribute value.

  

   Returns: true to indicate that this instance is equal to the 

    System.Windows.Forms.DataGridViewColumnDesignTimeVisibleAttribute.Default instance; otherwise,

    false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,visible=None):
  """
  __new__(cls: type,visible: bool)

  __new__(cls: type)
  """
  pass
 def __ne__(self,*args):
  pass
 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the column type is visible in the System.Windows.Forms.DataGridView designer.



Get: Visible(self: DataGridViewColumnDesignTimeVisibleAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class MaskedTextResultHint(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies values that succinctly describe the results of a masked text parsing operation.

 

 enum MaskedTextResultHint,values: AlphanumericCharacterExpected (-2),AsciiCharacterExpected (-1),CharacterEscaped (1),DigitExpected (-3),InvalidInput (-51),LetterExpected (-4),NoEffect (2),NonEditPosition (-54),PositionOutOfRange (-55),PromptCharNotAllowed (-52),SideEffect (3),SignedDigitExpected (-5),Success (4),UnavailableEditPosition (-53),Unknown (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AlphanumericCharacterExpected=None
 AsciiCharacterExpected=None
 CharacterEscaped=None
 DigitExpected=None
 InvalidInput=None
 LetterExpected=None
 NoEffect=None
 NonEditPosition=None
 PositionOutOfRange=None
 PromptCharNotAllowed=None
 SideEffect=None
 SignedDigitExpected=None
 Success=None
 UnavailableEditPosition=None
 Unknown=None
 value__=None




class DataGridViewCellStyleScopes(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the System.Windows.Forms.DataGridView entity that owns the cell style that was changed.

 

 enum (flags) DataGridViewCellStyleScopes,values: AlternatingRows (128),Cell (1),Column (2),ColumnHeaders (16),DataGridView (8),None (0),Row (4),RowHeaders (32),Rows (64)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AlternatingRows=None
 Cell=None
 Column=None
 ColumnHeaders=None
 DataGridView=None
 None=None
 Row=None
 RowHeaders=None
 Rows=None
 value__=None




# pylint: disable=missing-docstring,invalid-name,too-few-public-methods
"""Methods and Classes to convert Revit types to serializable."""
from pyrevit import PyRevitException, api
from pyrevit import DB
from pyrevit.compat import Iterable
from pyrevit import coreutils
from pyrevit.coreutils import logger
from pyrevit.compat import get_elementid_value_func


__all__ = ('serialize', 'deserialize')


mlogger = logger.get_logger(__name__)


class Serializable(object):
    # single type or a tuple of types
    api_types = None

    def __init__(self):
        pass

    def deserialize(self):
        return None


class EnumSerializable(Serializable):
    def __init__(self, enum_value):
        self.value = str(enum_value)

    def deserialize(self):
        return coreutils.get_enum_value(self.api_types, self.value)


class NoneSerializer(Serializable):
    pass


class ElementId(Serializable):
    api_types = DB.ElementId
    def __init__(self, element_id):
        get_elementid_value = get_elementid_value_func()
        self.integer_value = get_elementid_value(element_id)

    def deserialize(self):
        return DB.ElementId(self.integer_value)


class XYZ(Serializable):
    api_types = DB.XYZ

    def __init__(self, xyz):
        self.x = xyz.X
        self.y = xyz.Y
        self.z = xyz.Z

    def deserialize(self):
        return DB.XYZ(self.x, self.y, self.z)


class UV(Serializable):
    api_types = DB.UV

    def __init__(self, uv):
        self.u = uv.U
        self.v = uv.V

    def deserialize(self):
        return DB.UV(self.u, self.v)


class Line(Serializable):
    api_types = DB.Line

    def __init__(self, line):
        self.start = XYZ(line.GetEndPoint(0))
        self.end = XYZ(line.GetEndPoint(1))

    def deserialize(self):
        return DB.Line.CreateBound(self.start.deserialize(),
                                   self.end.deserialize())


class CurveLoop(Serializable):
    api_types = DB.CurveLoop

    def __init__(self, crv_loop):
        self.curves = []
        for crv in crv_loop:
            self.curves.append(serialize(crv))

    def deserialize(self):
        crv_loop = DB.CurveLoop()
        for crv in self.curves:
            crv_loop.Append(crv.deserialize())
        return crv_loop


class ViewOrientation3D(Serializable):
    api_types = DB.ViewOrientation3D

    def __init__(self, view_orientation_3d):
        self.eye = XYZ(view_orientation_3d.EyePosition)
        self.forward = XYZ(view_orientation_3d.ForwardDirection)
        self.up = XYZ(view_orientation_3d.UpDirection)

    def deserialize(self):
        return DB.ViewOrientation3D(self.eye.deserialize(),
                                    self.up.deserialize(),
                                    self.forward.deserialize())


class Transform(Serializable):
    api_types = DB.Transform

    def __init__(self, transform):
        self.basis_x = XYZ(transform.BasisX)
        self.basis_y = XYZ(transform.BasisY)
        self.basis_z = XYZ(transform.BasisZ)
        self.origin = XYZ(transform.Origin)
        self.scale = transform.Scale

    def deserialize(self):
        transform = DB.Transform.Identity
        transform.BasisX = self.basis_x.deserialize()
        transform.BasisY = self.basis_y.deserialize()
        transform.BasisZ = self.basis_z.deserialize()
        transform.Origin = self.origin.deserialize()
        transform.ScaleBasis(self.scale)
        return transform


class BoundingBoxXYZ(Serializable):
    api_types = DB.BoundingBoxXYZ

    def __init__(self, bbox_xyz):
        self.min = XYZ(bbox_xyz.Min)
        self.max = XYZ(bbox_xyz.Max)
        self.transform = Transform(bbox_xyz.Transform)

    def deserialize(self):
        bbox_xyz = DB.BoundingBoxXYZ()
        bbox_xyz.Min = self.min.deserialize()
        bbox_xyz.Max = self.max.deserialize()
        bbox_xyz.Transform = self.transform.deserialize()
        return bbox_xyz


class ViewType(EnumSerializable):
    api_types = DB.ViewType


class Grid(Serializable):
    api_types = DB.Grid

    def __init__(self, gridline):
        from rpw import doc

        cView = doc.ActiveView
        curves=gridline.GetCurvesInView(DB.DatumExtentType.ViewSpecific, cView)
        cCurve = curves[0]
        start_curve = gridline.GetLeader(DB.DatumEnds.End0, cView)
        end_curve = gridline.GetLeader(DB.DatumEnds.End1, cView)

        if start_curve:
          self.start_elbow = XYZ(start_curve.Elbow.X, start_curve.Elbow.Y, start_curve.Elbow.Z)
          self.start_leader = XYZ(start_curve.End.X, start_curve.End.Y, start_curve.End.Z)
          self.start_anchor = XYZ(start_curve.Anchor.X, start_curve.Anchor.Y, start_curve.Anchor.Z)

        if end_curve:
          self.end_elbow = XYZ(end_curve.Elbow.X, end_curve.Elbow.Y, end_curve.Elbow.Z)
          self.end_leader = XYZ(end_curve.End.X, end_curve.End.Y, end_curve.End.Z)
          self.end_anchor = XYZ(end_curve.Anchor.X, end_curve.Anchor.Y, end_curve.Anchor.Z)

        self.grid_name = gridline.Name
        self.start = XYZ(cCurve.GetEndPoint(0))
        self.end = XYZ(cCurve.GetEndPoint(1))

        if isinstance(cCurve, DB.Arc):
          self.center = XYZ(cCurve.Center.X, cCurve.Center.Y, cCurve.Center.Z)

        self.starts_with_bubble = gridline.HasBubbleInView(DB.DatumEnds.End0, cView)
        self.start_bubble_visible = gridline.IsBubbleVisibleInView(DB.DatumEnds.End0, cView)

        self.ends_with_bubble = gridline.HasBubbleInView(DB.DatumEnds.End1, cView)
        self.end_bubble_visible = gridline.IsBubbleVisibleInView(DB.DatumEnds.End1, cView)

    def deserialize(self):
        name = self.grid_name
        start = DB.XYZ(self.start.deserialize())
        end = DB.XYZ(self.end.deserialize())
        center = DB.XYZ(self.center.deserialize())
        bubble_start = {self.starts_with_bubble, self.start_bubble_visible}
        bubble_end = {self.ends_with_bubble, self.end_bubble_visible}
        start_curve = {self.start_leader, self.start_elbow, self.start_anchor}
        end_curve = {self.end_leader, self.end_elbow, self.end_anchor}

        return name, start, end, center, bubble_start, bubble_end, start_curve, end_curve


def _serialize_items(iterable_obj):
    result_list = []
    for api_item in iterable_obj:
        result_list.append(serialize(api_item))
    return result_list


def serialize(api_object):
    mlogger.debug('Attemping to serialize: %s', api_object)

    # wrap none in a none serializer for none values
    if api_object is None:
        return NoneSerializer()

    # make sure given type is a Revit API type
    if not api.is_api_object(api_object):
        raise PyRevitException("Only Revit API types are supported.")

    # get available serializers
    serializers = coreutils.get_all_subclasses(
        [Serializable, EnumSerializable]
        )

    # pick the compatible serializer
    try:
        compatible_serializer = \
            next(
                x for x in serializers
                if x.api_types and isinstance(api_object, x.api_types)
                )
        mlogger.debug('Serializer found for: %s', api_object)
        return compatible_serializer(api_object)
    except StopIteration:
        mlogger.debug('Serializer not found for: %s', api_object)
        # if no deserializer found,
        # see if given data is iterable
        # NOTE: commented this out since .serialize should only get api objects
        # if isinstance(api_object, Iterable):
        #     mlogger.debug('Iterating over: %s', api_object)
        #     return _serialize_items(api_object)

        # otherwise throw an exception
        raise PyRevitException(
            "No serializers have been implemented for \"%s\"" % repr(api_object)
            )


def deserialize(python_object):
    if isinstance(python_object, Iterable):
        result_list = []
        for python_item in python_object:
            result_list.append(deserialize(python_item))
        return result_list

    if isinstance(python_object, Serializable):
        return python_object.deserialize()



class HttpResponseHeader(Enum,IComparable,IFormattable,IConvertible):
 """
 The HTTP headers that can be specified in a server response.

 

 enum HttpResponseHeader,values: AcceptRanges (20),Age (21),Allow (10),CacheControl (0),Connection (1),ContentEncoding (13),ContentLanguage (14),ContentLength (11),ContentLocation (15),ContentMd5 (16),ContentRange (17),ContentType (12),Date (2),ETag (22),Expires (18),KeepAlive (3),LastModified (19),Location (23),Pragma (4),ProxyAuthenticate (24),RetryAfter (25),Server (26),SetCookie (27),Trailer (5),TransferEncoding (6),Upgrade (7),Vary (28),Via (8),Warning (9),WwwAuthenticate (29)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AcceptRanges=None
 Age=None
 Allow=None
 CacheControl=None
 Connection=None
 ContentEncoding=None
 ContentLanguage=None
 ContentLength=None
 ContentLocation=None
 ContentMd5=None
 ContentRange=None
 ContentType=None
 Date=None
 ETag=None
 Expires=None
 KeepAlive=None
 LastModified=None
 Location=None
 Pragma=None
 ProxyAuthenticate=None
 RetryAfter=None
 Server=None
 SetCookie=None
 Trailer=None
 TransferEncoding=None
 Upgrade=None
 value__=None
 Vary=None
 Via=None
 Warning=None
 WwwAuthenticate=None




class Binding(object):
 """
 Represents the simple binding between the property value of an object and the property value of a control.

 

 Binding(propertyName: str,dataSource: object,dataMember: str)

 Binding(propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool)

 Binding(propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,dataSourceUpdateMode: DataSourceUpdateMode)

 Binding(propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,dataSourceUpdateMode: DataSourceUpdateMode,nullValue: object)

 Binding(propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,dataSourceUpdateMode: DataSourceUpdateMode,nullValue: object,formatString: str)

 Binding(propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,dataSourceUpdateMode: DataSourceUpdateMode,nullValue: object,formatString: str,formatInfo: IFormatProvider)
 """
 def OnBindingComplete(self,*args):
  """
  OnBindingComplete(self: Binding,e: BindingCompleteEventArgs)

   Raises the System.Windows.Forms.Binding.BindingComplete event.

  

   e: A System.Windows.Forms.BindingCompleteEventArgs  that contains the event data.
  """
  pass
 def OnFormat(self,*args):
  """
  OnFormat(self: Binding,cevent: ConvertEventArgs)

   Raises the System.Windows.Forms.Binding.Format event.

  

   cevent: A System.Windows.Forms.ConvertEventArgs that contains the event data.
  """
  pass
 def OnParse(self,*args):
  """
  OnParse(self: Binding,cevent: ConvertEventArgs)

   Raises the System.Windows.Forms.Binding.Parse event.

  

   cevent: A System.Windows.Forms.ConvertEventArgs that contains the event data.
  """
  pass
 def ReadValue(self):
  """
  ReadValue(self: Binding)

   Sets the control property to the value read from the data source.
  """
  pass
 def WriteValue(self):
  """
  WriteValue(self: Binding)

   Reads the current value from the control property and writes it to the data source.
  """
  pass
 @staticmethod
 def __new__(self,propertyName,dataSource,dataMember,formattingEnabled=None,dataSourceUpdateMode=None,nullValue=None,formatString=None,formatInfo=None):
  """
  __new__(cls: type,propertyName: str,dataSource: object,dataMember: str)

  __new__(cls: type,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool)

  __new__(cls: type,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,dataSourceUpdateMode: DataSourceUpdateMode)

  __new__(cls: type,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,dataSourceUpdateMode: DataSourceUpdateMode,nullValue: object)

  __new__(cls: type,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,dataSourceUpdateMode: DataSourceUpdateMode,nullValue: object,formatString: str)

  __new__(cls: type,propertyName: str,dataSource: object,dataMember: str,formattingEnabled: bool,dataSourceUpdateMode: DataSourceUpdateMode,nullValue: object,formatString: str,formatInfo: IFormatProvider)
  """
  pass
 BindableComponent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the control the System.Windows.Forms.Binding is associated with.



Get: BindableComponent(self: Binding) -> IBindableComponent



"""

 BindingManagerBase=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.BindingManagerBase for this System.Windows.Forms.Binding.



Get: BindingManagerBase(self: Binding) -> BindingManagerBase



"""

 BindingMemberInfo=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object that contains information about this binding based on the dataMember parameter in the erload:System.Windows.Forms.Binding.#ctor constructor.



Get: BindingMemberInfo(self: Binding) -> BindingMemberInfo



"""

 Control=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the control that the binding belongs to.



Get: Control(self: Binding) -> Control



"""

 ControlUpdateMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets when changes to the data source are propagated to the bound control property.



Get: ControlUpdateMode(self: Binding) -> ControlUpdateMode



Set: ControlUpdateMode(self: Binding)=value

"""

 DataSource=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the data source for this binding.



Get: DataSource(self: Binding) -> object



"""

 DataSourceNullValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value to be stored in the data source if the control value is null or empty.



Get: DataSourceNullValue(self: Binding) -> object



Set: DataSourceNullValue(self: Binding)=value

"""

 DataSourceUpdateMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates when changes to the bound control property are propagated to the data source.



Get: DataSourceUpdateMode(self: Binding) -> DataSourceUpdateMode



Set: DataSourceUpdateMode(self: Binding)=value

"""

 FormatInfo=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.IFormatProvider that provides custom formatting behavior.



Get: FormatInfo(self: Binding) -> IFormatProvider



Set: FormatInfo(self: Binding)=value

"""

 FormatString=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the format specifier characters that indicate how a value is to be displayed.



Get: FormatString(self: Binding) -> str



Set: FormatString(self: Binding)=value

"""

 FormattingEnabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether type conversion and formatting is applied to the control property data.



Get: FormattingEnabled(self: Binding) -> bool



Set: FormattingEnabled(self: Binding)=value

"""

 IsBinding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the binding is active.



Get: IsBinding(self: Binding) -> bool



"""

 NullValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Object to be set as the control property when the data source contains a System.DBNull value.



Get: NullValue(self: Binding) -> object



Set: NullValue(self: Binding)=value

"""

 PropertyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the control's data-bound property.



Get: PropertyName(self: Binding) -> str



"""


 BindingComplete=None
 Format=None
 Parse=None




from typing import Tuple, Set, Iterable, List


class WiringType:
    Arc = 0
    Chamfer = 1


class PowerFactorStateType:
    Leading = 0
    Lagging = 1


class CircuitType:
    Circuit = 0
    Spare = 1
    Space = 2


class LoadClassification:
    Undefined = 0
    Power = 1
    Lighting = 2
    Hvac = 3


class CircuitConnectionType:
    NotApplicable = 0
    Breaker = 1
    FeedThruLugs = 2


class CircuitNumberingOption:
    Default = 0
    Continuous = 1


class CircuitNaming:
    Prefixed = 0
    Standard = 1
    PanelName = 2
    Phase = 3
    ProjectSetting = 4
    Customized = 5
    Undefined = -1


class ElectricalSystemType:
    UndefinedSystemType = 0
    Data = 5
    PowerCircuit = 6
    Telephone = 9
    Security = 10
    FireAlarm = 11
    NurseCall = 12
    Controls = 13
    Communication = 14
    PowerBalanced = 30
    PowerUnBalanced = 31


class ElectricalPhase:
    SinglePhase = 0
    ThreePhase = 1


class ElectricalPhaseConfiguration:
    Undefined = 0
    Wye = 1
    Delta = 2


class LoadClassificationType:
    Other = 0
    Power = 1
    Lighting = 2
    HVAC = 3


class ElectricalSystemSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> ElectricalSystemSetIterator: ...
    def ReverseIterator(self) -> ElectricalSystemSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: ElectricalSystem) -> bool: ...
    def Insert(self, item: ElectricalSystem) -> bool: ...
    def Erase(self, item: ElectricalSystem) -> int: ...


class ElectricalSystemSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class ElectricalSystem(MEPSystem):
    def AddToCircuit(self, components: ElementSet) -> bool: ...
    def RemoveFromCircuit(self, components: ElementSet) -> None: ...
    def NewWires(self, view: View, wiringType: WiringType) -> WireSet: ...
    @property
    def CircuitNumber(self) -> str: ...
    @property
    def CircuitNamingIndex(self) -> int: ...
    @property
    def StartSlot(self) -> int: ...
    @property
    def SlotIndex(self) -> str: ...
    @property
    def WireType(self) -> WireType: ...
    @WireType.setter
    def WireType(self, wireType: WireType) -> None: ...
    @property
    def LoadName(self) -> str: ...
    @LoadName.setter
    def LoadName(self, strValue: str) -> None: ...
    @property
    def WireSizeString(self) -> str: ...
    @property
    def Voltage(self) -> float: ...
    @property
    def ApparentLoad(self) -> float: ...
    @property
    def ApparentLoadPhaseA(self) -> float: ...
    @property
    def ApparentLoadPhaseB(self) -> float: ...
    @property
    def ApparentLoadPhaseC(self) -> float: ...
    @property
    def PowerFactor(self) -> float: ...
    @property
    def TrueLoad(self) -> float: ...
    @TrueLoad.setter
    def TrueLoad(self, trueLoad: float) -> None: ...
    @property
    def TrueLoadPhaseA(self) -> float: ...
    @property
    def TrueLoadPhaseB(self) -> float: ...
    @property
    def TrueLoadPhaseC(self) -> float: ...
    @property
    def Rating(self) -> float: ...
    @Rating.setter
    def Rating(self, rating: float) -> None: ...
    @property
    def PathOffset(self) -> float: ...
    @PathOffset.setter
    def PathOffset(self, pathOffset: float) -> None: ...
    @property
    def HasPathOffset(self) -> bool: ...
    @property
    def Frame(self) -> float: ...
    @Frame.setter
    def Frame(self, frame: float) -> None: ...
    @property
    def Length(self) -> float: ...
    @property
    def ApparentCurrent(self) -> float: ...
    @property
    def ApparentCurrentPhaseA(self) -> float: ...
    @property
    def ApparentCurrentPhaseB(self) -> float: ...
    @property
    def ApparentCurrentPhaseC(self) -> float: ...
    @property
    def TrueCurrent(self) -> float: ...
    @property
    def TrueCurrentPhaseA(self) -> float: ...
    @property
    def TrueCurrentPhaseB(self) -> float: ...
    @property
    def TrueCurrentPhaseC(self) -> float: ...
    @property
    def VoltageDrop(self) -> float: ...
    @property
    def SystemType(self) -> ElectricalSystemType: ...
    @property
    def PowerFactorState(self) -> PowerFactorStateType: ...
    @property
    def LoadClassifications(self) -> str: ...
    @property
    def LoadClassificationAbbreviations(self) -> str: ...
    @property
    def PhaseLabel(self) -> str: ...
    @property
    def Ways(self) -> int: ...
    @property
    def PolesNumber(self) -> int: ...
    @property
    def BalancedLoad(self) -> bool: ...
    @property
    def RunsNumber(self) -> int: ...
    @property
    def HotConductorsNumber(self) -> int: ...
    @property
    def NeutralConductorsNumber(self) -> int: ...
    @NeutralConductorsNumber.setter
    def NeutralConductorsNumber(self, numNeutrals: int) -> None: ...
    @property
    def GroundConductorsNumber(self) -> int: ...
    @property
    def CircuitType(self) -> CircuitType: ...
    @property
    def PanelName(self) -> str: ...
    @property
    def IsBasePanelFeedThroughLugsOccupied(self) -> bool: ...
    @property
    def HasCustomCircuitPath(self) -> bool: ...
    @property
    def CircuitPathMode(self) -> ElectricalCircuitPathMode: ...
    @CircuitPathMode.setter
    def CircuitPathMode(self, circuitPathMode: ElectricalCircuitPathMode) -> None: ...
    @property
    def CircuitConnectionType(self) -> CircuitConnectionType: ...
    @CircuitConnectionType.setter
    def CircuitConnectionType(self, circuitConnectionType: CircuitConnectionType) -> None: ...
    @overload
    def Create(connector: Connector, elecSysType: ElectricalSystemType) -> ElectricalSystem: ...
    @overload
    def Create(document: Document, electComponents: List[ElementId], elecSysType: ElectricalSystemType) -> ElectricalSystem: ...
    def SelectPanel(self, panel: FamilyInstance) -> None: ...
    def DisconnectPanel(self) -> None: ...
    def GetCircuitPath(self) -> List[XYZ]: ...
    def SetCircuitPath(self, nodes: List[XYZ]) -> None: ...
    def IsCircuitPathValid(self, nodes: List[XYZ]) -> bool: ...


class ElectricalCircuitPathMode:
    Custom = 0
    FarthestDevice = 1
    AllDevices = 2


class Wire(MEPCurve):
    @property
    def WiringType(self) -> WiringType: ...
    @WiringType.setter
    def WiringType(self, wiringType: WiringType) -> None: ...
    @property
    def HotConductorNum(self) -> int: ...
    @HotConductorNum.setter
    def HotConductorNum(self, hotConductorNum: int) -> None: ...
    @property
    def NeutralConductorNum(self) -> int: ...
    @NeutralConductorNum.setter
    def NeutralConductorNum(self, neutralConductorNum: int) -> None: ...
    @property
    def GroundConductorNum(self) -> int: ...
    @GroundConductorNum.setter
    def GroundConductorNum(self, groundConductorNum: int) -> None: ...
    @property
    def NumberOfVertices(self) -> int: ...
    def Create(document: Document, wireTypeId: ElementId, viewId: ElementId, wiringType: WiringType, vertexPoints: List[XYZ], startConnectorTo: Connector, endConnectorTo: Connector) -> Wire: ...
    def ConnectTo(self, startConnectorTo: Connector, endConnectorTo: Connector) -> None: ...
    def AreVertexPointsValid(vertexPoints: List[XYZ], startConnector: Connector, endConnector: Connector) -> bool: ...
    def AppendVertex(self, vertexPoint: XYZ) -> None: ...
    def InsertVertex(self, index: int, vertexPoint: XYZ) -> None: ...
    def RemoveVertex(self, index: int) -> None: ...
    def SetVertex(self, index: int, vertexPoint: XYZ) -> None: ...
    def GetVertex(self, index: int) -> XYZ: ...
    def IsVertexPointValid(self, vertexPoint: XYZ) -> bool: ...
    def GetMEPSystems(self) -> List[ElementId]: ...


class WireSize(APIObject):
    @property
    def Ampacity(self) -> Int64: ...
    @property
    def Size(self) -> str: ...
    @property
    def Diameter(self) -> float: ...
    @property
    def InUse(self) -> bool: ...
    @InUse.setter
    def InUse(self, A_0: bool) -> None: ...


class CorrectionFactor(APIObject):
    @property
    def Temperature(self) -> Int64: ...
    @property
    def Factor(self) -> float: ...


class GroundConductorSize(APIObject):
    @property
    def MaterialBelongTo(self) -> WireMaterialType: ...
    @property
    def Ampacity(self) -> Int64: ...
    @property
    def ConductorSize(self) -> str: ...


class InsulationType(ElementType):
    @Name.setter
    def Name(self, A_0: str) -> None: ...
    @property
    def IsInUse(self) -> bool: ...


class TemperatureRatingType(ElementType):
    @Name.setter
    def Name(self, A_0: str) -> None: ...
    @property
    def MaterialType(self) -> WireMaterialType: ...
    @property
    def InsulationTypes(self) -> InsulationTypeSet: ...
    @property
    def WireSizes(self) -> WireSizeSet: ...
    @property
    def CorrectionFactors(self) -> CorrectionFactorSet: ...
    @property
    def IsInUse(self) -> bool: ...
    def AddInsulationType(self, name: str) -> InsulationType: ...
    def RemoveInsulationType(self, insulationType: InsulationType) -> None: ...
    def AddWireSize(self, size: str, ampacity: Int64, diameter: float) -> WireSize: ...
    def RemoveWireSize(self, wireSize: WireSize) -> None: ...
    def AddCorrectionFactor(self, temperature: Int64, factor: float) -> CorrectionFactor: ...
    def RemoveCorrectionFactor(self, correctionFactor: CorrectionFactor) -> None: ...


class WireMaterialType(ElementType):
    @Name.setter
    def Name(self, A_0: str) -> None: ...
    @property
    def TemperatureRatings(self) -> TemperatureRatingTypeSet: ...
    @property
    def GroundConductorSizes(self) -> GroundConductorSizeSet: ...
    @property
    def IsInUse(self) -> bool: ...
    def AddTemperatureRatingType(self, name: str, baseOn: TemperatureRatingType) -> TemperatureRatingType: ...
    def RemoveTemperatureRatingType(self, temperatureRating: TemperatureRatingType) -> None: ...
    def AddGroundConductorSize(self, ampacity: Int64, size: str) -> GroundConductorSize: ...
    def RemoveGroundConductorSize(self, grdConductorSize: GroundConductorSize) -> None: ...


class WireConduitType(APIObject):
    @property
    def Name(self) -> str: ...


class WireType(ElementType):
    @property
    def WireMaterial(self) -> WireMaterialType: ...
    @WireMaterial.setter
    def WireMaterial(self, A_0: WireMaterialType) -> None: ...
    @property
    def TemperatureRating(self) -> TemperatureRatingType: ...
    @TemperatureRating.setter
    def TemperatureRating(self, A_0: TemperatureRatingType) -> None: ...
    @property
    def Insulation(self) -> InsulationType: ...
    @Insulation.setter
    def Insulation(self, A_0: InsulationType) -> None: ...
    @property
    def MaxSize(self) -> WireSize: ...
    @MaxSize.setter
    def MaxSize(self, A_0: WireSize) -> None: ...
    @property
    def NeutralMultiplier(self) -> float: ...
    @NeutralMultiplier.setter
    def NeutralMultiplier(self, A_0: float) -> None: ...
    @property
    def NeutralRequired(self) -> bool: ...
    @NeutralRequired.setter
    def NeutralRequired(self, A_0: bool) -> None: ...
    @property
    def NeutralSize(self) -> NeutralMode: ...
    @NeutralSize.setter
    def NeutralSize(self, A_0: NeutralMode) -> None: ...
    @property
    def Conduit(self) -> WireConduitType: ...
    @Conduit.setter
    def Conduit(self, A_0: WireConduitType) -> None: ...
    @property
    def IsInUse(self) -> bool: ...


class ElectricalSetting(Element):
    @property
    def VoltageTypes(self) -> VoltageTypeSet: ...
    @property
    def WireTypes(self) -> WireTypeSet: ...
    @property
    def DistributionSysTypes(self) -> DistributionSysTypeSet: ...
    @property
    def WireMaterialTypes(self) -> WireMaterialTypeSet: ...
    @property
    def WireConduitTypes(self) -> WireConduitTypeSet: ...
    def AddVoltageType(self, name: str, actualValue: float, minValue: float, maxValue: float) -> VoltageType: ...
    def RemoveVoltageType(self, voltageType: VoltageType) -> None: ...
    def AddDistributionSysType(self, name: str, phase: ElectricalPhase, phaseConfig: ElectricalPhaseConfiguration, numWire: int, volLineToLine: VoltageType, volLineToGround: VoltageType) -> DistributionSysType: ...
    def RemoveDistributionSysType(self, distributionSysType: DistributionSysType) -> None: ...
    def AddWireMaterialType(self, name: str, baseMaterial: WireMaterialType) -> WireMaterialType: ...
    def RemoveWireMaterialType(self, materialType: WireMaterialType) -> None: ...
    def AddWireType(self, name: str, materialType: WireMaterialType, temperatureRating: TemperatureRatingType, insulation: InsulationType, maxSize: WireSize, neutralMultiplier: float, neutralRequired: bool, neutralMode: NeutralMode, conduit: WireConduitType) -> WireType: ...
    def RemoveWireType(self, wireType: WireType) -> None: ...
    @property
    def CircuitNamePhaseA(self) -> str: ...
    @CircuitNamePhaseA.setter
    def CircuitNamePhaseA(self, circuitNamePhaseA: str) -> None: ...
    @property
    def CircuitNamePhaseB(self) -> str: ...
    @CircuitNamePhaseB.setter
    def CircuitNamePhaseB(self, circuitNamePhaseB: str) -> None: ...
    @property
    def CircuitNamePhaseC(self) -> str: ...
    @CircuitNamePhaseC.setter
    def CircuitNamePhaseC(self, circuitNamePhaseC: str) -> None: ...
    @property
    def CircuitRating(self) -> float: ...
    @CircuitRating.setter
    def CircuitRating(self, circuitRating: float) -> None: ...
    @property
    def CircuitPathOffset(self) -> float: ...
    @CircuitPathOffset.setter
    def CircuitPathOffset(self, circuitPathOffset: float) -> None: ...
    @property
    def CircuitLoadCalculationMethod(self) -> CircuitLoadCalculationMethod: ...
    @CircuitLoadCalculationMethod.setter
    def CircuitLoadCalculationMethod(self, circuitLoadCalculationMethod: CircuitLoadCalculationMethod) -> None: ...
    @property
    def CircuitSequence(self) -> CircuitSequence: ...
    @CircuitSequence.setter
    def CircuitSequence(self, circuitSequence: CircuitSequence) -> None: ...
    def GetElectricalSettings(document: Document) -> ElectricalSetting: ...
    def GetCircuitNamingSchemeSettings(cda: Document) -> CircuitNamingSchemeSettings: ...
    def GetSpecificFittingAngles(self) -> List[float]: ...
    def SetSpecificFittingAngleStatus(self, angle: float, bStatus: bool) -> None: ...
    def GetSpecificFittingAngleStatus(self, angle: float) -> bool: ...
    def IsValidSpecificFittingAngle(self, angle: float) -> bool: ...


class NeutralMode:
    HotConductorSize = 0
    UnbalancedCurrent = 1


class CapitalizationForLoadNames:
    SourceParameters = 0
    Initial = 1
    Sentence = 2
    Upper = 3


class CircuitSequence:
    Numerical = 0
    GroupByPhase = 1
    OddThenEven = 2


class CircuitLoadCalculationMethod:
    SumTrueLoadAndReactiveLoad = 0
    SumApparentLoad = 1


class ElectricalEquipment(MEPModel):
    @property
    def DistributionSystem(self) -> DistributionSysType: ...
    @DistributionSystem.setter
    def DistributionSystem(self, distributionSystem: DistributionSysType) -> None: ...
    @property
    def CircuitNamingSchemeId(self) -> ElementId: ...
    @CircuitNamingSchemeId.setter
    def CircuitNamingSchemeId(self, idCircuitNamingScheme: ElementId) -> None: ...
    @property
    def MaxNumberOfCircuits(self) -> int: ...
    @MaxNumberOfCircuits.setter
    def MaxNumberOfCircuits(self, nMaxNumberOfCircuits: int) -> None: ...
    @property
    def IsSwitchboard(self) -> bool: ...
    def IsValidDistributionSystem(self, distributionSystem: DistributionSysType) -> bool: ...
    def IsValidCircuitNamingSchemeId(aDocument: Document, circuitNamingSchemeId: ElementId) -> bool: ...
    def GetCircuitNamingSchemeType(self) -> CircuitNaming: ...
    def SetCircuitNamingSchemeType(self, circuitNamingType: CircuitNaming) -> None: ...


class LightingDevice(MEPModel):


class LightingFixture(MEPModel):


class VoltageType(ElementType):
    @property
    def ActualValue(self) -> float: ...
    @property
    def MaxValue(self) -> float: ...
    @property
    def MinValue(self) -> float: ...
    @property
    def IsInUse(self) -> bool: ...
    def SetVoltageValue(self, actualValue: float, minValue: float, maxValue: float) -> None: ...


class DistributionSysType(ElementType):
    @property
    def ElectricalPhaseConfiguration(self) -> ElectricalPhaseConfiguration: ...
    @ElectricalPhaseConfiguration.setter
    def ElectricalPhaseConfiguration(self, A_0: ElectricalPhaseConfiguration) -> None: ...
    @property
    def ElectricalPhase(self) -> ElectricalPhase: ...
    @ElectricalPhase.setter
    def ElectricalPhase(self, A_0: ElectricalPhase) -> None: ...
    @property
    def NumWires(self) -> int: ...
    @NumWires.setter
    def NumWires(self, A_0: int) -> None: ...
    @property
    def VoltageLineToLine(self) -> VoltageType: ...
    @VoltageLineToLine.setter
    def VoltageLineToLine(self, A_0: VoltageType) -> None: ...
    @property
    def VoltageLineToGround(self) -> VoltageType: ...
    @VoltageLineToGround.setter
    def VoltageLineToGround(self, A_0: VoltageType) -> None: ...
    @property
    def IsInUse(self) -> bool: ...


class DistributionSysTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> DistributionSysTypeSetIterator: ...
    def ReverseIterator(self) -> DistributionSysTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: DistributionSysType) -> bool: ...
    def Insert(self, item: DistributionSysType) -> bool: ...
    def Erase(self, item: DistributionSysType) -> int: ...


class DistributionSysTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class VoltageTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> VoltageTypeSetIterator: ...
    def ReverseIterator(self) -> VoltageTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: VoltageType) -> bool: ...
    def Insert(self, item: VoltageType) -> bool: ...
    def Erase(self, item: VoltageType) -> int: ...


class VoltageTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class WireSizeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> WireSizeSetIterator: ...
    def ReverseIterator(self) -> WireSizeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: WireSize) -> bool: ...
    def Insert(self, item: WireSize) -> bool: ...
    def Erase(self, item: WireSize) -> int: ...


class WireSizeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class GroundConductorSizeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> GroundConductorSizeSetIterator: ...
    def ReverseIterator(self) -> GroundConductorSizeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: GroundConductorSize) -> bool: ...
    def Insert(self, item: GroundConductorSize) -> bool: ...
    def Erase(self, item: GroundConductorSize) -> int: ...


class GroundConductorSizeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class CorrectionFactorSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> CorrectionFactorSetIterator: ...
    def ReverseIterator(self) -> CorrectionFactorSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: CorrectionFactor) -> bool: ...
    def Insert(self, item: CorrectionFactor) -> bool: ...
    def Erase(self, item: CorrectionFactor) -> int: ...


class CorrectionFactorSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class WireConduitTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> WireConduitTypeSetIterator: ...
    def ReverseIterator(self) -> WireConduitTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: WireConduitType) -> bool: ...
    def Insert(self, item: WireConduitType) -> bool: ...
    def Erase(self, item: WireConduitType) -> int: ...


class WireConduitTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class WireMaterialTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> WireMaterialTypeSetIterator: ...
    def ReverseIterator(self) -> WireMaterialTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: WireMaterialType) -> bool: ...
    def Insert(self, item: WireMaterialType) -> bool: ...
    def Erase(self, item: WireMaterialType) -> int: ...


class WireMaterialTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class TemperatureRatingTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> TemperatureRatingTypeSetIterator: ...
    def ReverseIterator(self) -> TemperatureRatingTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: TemperatureRatingType) -> bool: ...
    def Insert(self, item: TemperatureRatingType) -> bool: ...
    def Erase(self, item: TemperatureRatingType) -> int: ...


class TemperatureRatingTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class InsulationTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> InsulationTypeSetIterator: ...
    def ReverseIterator(self) -> InsulationTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: InsulationType) -> bool: ...
    def Insert(self, item: InsulationType) -> bool: ...
    def Erase(self, item: InsulationType) -> int: ...


class InsulationTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class WireTypeSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> WireTypeSetIterator: ...
    def ReverseIterator(self) -> WireTypeSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: WireType) -> bool: ...
    def Insert(self, item: WireType) -> bool: ...
    def Erase(self, item: WireType) -> int: ...


class WireTypeSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class WireSet(APIObject):
    def __init__(self): ...
    def Clear(self) -> None: ...
    @property
    def Size(self) -> int: ...
    @property
    def IsEmpty(self) -> bool: ...
    def ForwardIterator(self) -> WireSetIterator: ...
    def ReverseIterator(self) -> WireSetIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Contains(self, item: Wire) -> bool: ...
    def Insert(self, item: Wire) -> bool: ...
    def Erase(self, item: Wire) -> int: ...


class WireSetIterator(APIObject):
    def __init__(self): ...
    @property
    def Current(self) -> Object: ...
    def MoveNext(self) -> bool: ...
    def Reset(self) -> None: ...


class PanelSchedulePhaseLoadType:
    NoLoadInformation = 0
    LoadsByPhaseInSplitColumns = 1
    MirroredPhaseColumns = 2
    LoadsByPhaseInSharedColumns = 3
    LoadsByPhase = 4
    TotalLoadOnlyPerCircuit = 5
    SeperatePhaseLoadsPerCircuit = 6


class CableTrayConduitBase(MEPCurve):
    @property
    def RunId(self) -> ElementId: ...
    def IsWithFitting(self) -> bool: ...
    def IsValidLevelId(document: Document, levelId: ElementId) -> bool: ...
    def IsValidEndPoints(startPoint: XYZ, endPoint: XYZ) -> bool: ...


class CableTray(CableTrayConduitBase):
    @property
    def RungSpace(self) -> float: ...
    @RungSpace.setter
    def RungSpace(self, rungSpace: float) -> None: ...
    @property
    def CurveNormal(self) -> XYZ: ...
    @CurveNormal.setter
    def CurveNormal(self, normal: XYZ) -> None: ...
    def Create(document: Document, cabletrayType: ElementId, startPoint: XYZ, endPoint: XYZ, levelId: ElementId) -> CableTray: ...
    def IsValidCableTrayType(document: Document, cabletrayType: ElementId) -> bool: ...
    def GetShapeType(self) -> CableTrayShape: ...
    def IsValidRungSpace(self, rungSpace: float) -> bool: ...


class CableTrayConduitRunBase(Element):
    @property
    def Length(self) -> float: ...


class CableTrayRun(CableTrayConduitRunBase):


class CableTraySettings(Element):
    @property
    def SizeSeparator(self) -> str: ...
    @SizeSeparator.setter
    def SizeSeparator(self, sizeSeparator: str) -> None: ...
    @property
    def SizeSuffix(self) -> str: ...
    @SizeSuffix.setter
    def SizeSuffix(self, sizeSuffix: str) -> None: ...
    @property
    def ConnectorSeparator(self) -> str: ...
    @ConnectorSeparator.setter
    def ConnectorSeparator(self, connectorSeparator: str) -> None: ...
    @property
    def FittingAnnotationSize(self) -> float: ...
    @FittingAnnotationSize.setter
    def FittingAnnotationSize(self, fittingAnnotationSize: float) -> None: ...
    @property
    def RiseDropAnnotationSize(self) -> float: ...
    @RiseDropAnnotationSize.setter
    def RiseDropAnnotationSize(self, riseDropAnnotationSize: float) -> None: ...
    @property
    def UseAnnotationScaleForSingleLineFittings(self) -> bool: ...
    @UseAnnotationScaleForSingleLineFittings.setter
    def UseAnnotationScaleForSingleLineFittings(self, useAnnotationScaleForSingleLineFittings: bool) -> None: ...
    def GetCableTraySettings(document: Document) -> CableTraySettings: ...


class CableTraySizeIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    def GetCurrent(self) -> MEPSize: ...
    def HasCurrent(self) -> bool: ...
    @property
    def Current(self) -> MEPSize: ...
    def Dispose(self) -> None: ...


class CableTraySizes(Element):
    def GetSizeCount(self) -> int: ...
    def Contains(self, nominalDiameter: float) -> bool: ...
    def GetCableTraySizes(aDoc: Document) -> CableTraySizes: ...
    def AddSize(self, sizeInfo: MEPSize) -> None: ...
    def RemoveSize(self, sizeInfo: MEPSize) -> None: ...
    def ClearAll(self) -> None: ...
    def GetCableTraySizesIterator(self) -> CableTraySizeIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...


class CableTrayType(MEPCurveType):
    @property
    def BendMultiplier(self) -> float: ...
    @BendMultiplier.setter
    def BendMultiplier(self, bendMultiplier: float) -> None: ...
    @property
    def ShapeType(self) -> CableTrayShape: ...
    @property
    def IsWithFitting(self) -> bool: ...
    def IsValidBendMultiplier(self, bendMultiplier: float) -> bool: ...


class CircuitNamingScheme(Element):
    def Create(document: Document, name: str, data: List[TableCellCombinedParameterData]) -> CircuitNamingScheme: ...
    def IsValidCombinedParameters(aDocument: Document, data: List[TableCellCombinedParameterData]) -> bool: ...
    def IsNameUnique(aDocument: Document, name: str) -> bool: ...
    def GetCombinedParameters(self) -> List[TableCellCombinedParameterData]: ...
    def SetCombinedParameters(self, data: List[TableCellCombinedParameterData]) -> None: ...


class CircuitNamingSchemeSettings(Element):
    @property
    def CircuitNamingSchemeId(self) -> ElementId: ...
    @CircuitNamingSchemeId.setter
    def CircuitNamingSchemeId(self, circuitNamingSchemeId: ElementId) -> None: ...
    def GetCircuitNamingSchemeSettings(cda: Document) -> CircuitNamingSchemeSettings: ...
    def IsValidCircuitNamingSchemeId(aDocument: Document, circuitNamingSchemeId: ElementId) -> bool: ...


class Conduit(CableTrayConduitBase):
    def Create(document: Document, conduitType: ElementId, startPoint: XYZ, endPoint: XYZ, levelId: ElementId) -> Conduit: ...
    def IsValidConduitType(document: Document, conduitType: ElementId) -> bool: ...


class ConduitRun(CableTrayConduitRunBase):


class ConduitSettings(Element):
    @property
    def SizeSuffix(self) -> str: ...
    @SizeSuffix.setter
    def SizeSuffix(self, sizeSuffix: str) -> None: ...
    @property
    def SizePrefix(self) -> str: ...
    @SizePrefix.setter
    def SizePrefix(self, sizePrefix: str) -> None: ...
    @property
    def ConnectorSeparator(self) -> str: ...
    @ConnectorSeparator.setter
    def ConnectorSeparator(self, connectorSeparator: str) -> None: ...
    @property
    def FittingAnnotationSize(self) -> float: ...
    @FittingAnnotationSize.setter
    def FittingAnnotationSize(self, fittingAnnotationSize: float) -> None: ...
    @property
    def RiseDropAnnotationSize(self) -> float: ...
    @RiseDropAnnotationSize.setter
    def RiseDropAnnotationSize(self, riseDropAnnotationSize: float) -> None: ...
    @property
    def UseAnnotationScaleForSingleLineFittings(self) -> bool: ...
    @UseAnnotationScaleForSingleLineFittings.setter
    def UseAnnotationScaleForSingleLineFittings(self, useAnnotationScaleForSingleLineFittings: bool) -> None: ...
    def GetConduitSettings(document: Document) -> ConduitSettings: ...


class ConduitSize:
    def __init__(self, nominalDiameter: float, innerDiameter: float, outerDiameter: float, bendRadius: float, usedInSizeLists: bool, usedInSizing: bool): ...
    @property
    def NominalDiameter(self) -> float: ...
    @property
    def InnerDiameter(self) -> float: ...
    @property
    def OuterDiameter(self) -> float: ...
    @property
    def BendRadius(self) -> float: ...
    @property
    def UsedInSizeLists(self) -> bool: ...
    @property
    def UsedInSizing(self) -> bool: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class ConduitSizeIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    def GetCurrent(self) -> ConduitSize: ...
    def HasCurrent(self) -> bool: ...
    @property
    def Current(self) -> ConduitSize: ...
    def Dispose(self) -> None: ...


class ConduitSizes:
    @property
    def Count(self) -> int: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Contains(self, nominalDiameter: float) -> bool: ...
    def GetConduitSizesIterator(self) -> ConduitSizeIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...
    def Dispose(self) -> None: ...


class ConduitSizeSettingIterator:
    @property
    def IsValidObject(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Reset(self) -> None: ...
    def HasCurrent(self) -> bool: ...
    @property
    def Current(self) -> KeyValuePair: ...
    def Dispose(self) -> None: ...


class ConduitSizeSettings(Element):
    def GetConduitSizeSettings(aDoc: Document) -> ConduitSizeSettings: ...
    def GetSizeCount(self, standardName: str) -> int: ...
    def AddSize(self, standardName: str, sizeInfo: ConduitSize) -> None: ...
    def RemoveSize(self, standardName: str, nominalDiameter: float) -> None: ...
    def CreateConduitStandardTypeFromExisingStandardType(self, pADoc: Document, newStandardName: str, existingStandardName: str) -> bool: ...
    def DoesConduitStandardTypeExist(self, standardName: str) -> bool: ...
    def RemoveConduitStandardType(self, pADoc: Document, standardName: str) -> bool: ...
    def GetConduitSizeSettingsIterator(self) -> ConduitSizeSettingIterator: ...
    def GetEnumerator(self) -> IEnumerator: ...


class ConduitType(MEPCurveType):
    @property
    def IsWithFitting(self) -> bool: ...


class CableTrayShape:
    Invalid = 0
    Channel = 1
    Ladder = 2


class ElectricalDemandFactorDefinition(Element):
    def __init__(self): ...
    @property
    def AdditionalLoad(self) -> float: ...
    @AdditionalLoad.setter
    def AdditionalLoad(self, additionalLoad: float) -> None: ...
    @property
    def RuleType(self) -> ElectricalDemandFactorRule: ...
    @RuleType.setter
    def RuleType(self, ruleType: ElectricalDemandFactorRule) -> None: ...
    @property
    def IncludeAdditionalLoad(self) -> bool: ...
    @IncludeAdditionalLoad.setter
    def IncludeAdditionalLoad(self, includeAdditionalLoad: bool) -> None: ...
    def Create(ADoc: Document, strName: str) -> ElectricalDemandFactorDefinition: ...
    def ClearValues(self) -> None: ...
    def AddValue(self, dfValue: ElectricalDemandFactorValue) -> None: ...
    def RemoveValue(self, dfValue: ElectricalDemandFactorValue) -> None: ...
    def SetValues(self, values: ICollection) -> None: ...
    def GetValues(self) -> ICollection: ...
    def GetValuesCount(self) -> int: ...
    def GetApplicableDemandFactor(self, numberOrLoad: float) -> float: ...


class ElectricalDemandFactorValue:
    @overload
    def __init__(self, minRange: float, maxRange: float, factor: float): ...
    @overload
    def __init__(self): ...
    @property
    def Factor(self) -> float: ...
    @Factor.setter
    def Factor(self, factor: float) -> None: ...
    @property
    def MinRange(self) -> float: ...
    @MinRange.setter
    def MinRange(self, minRange: float) -> None: ...
    @property
    def MaxRange(self) -> float: ...
    @MaxRange.setter
    def MaxRange(self, maxRange: float) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def SetMaxRangeToUnlimited(self) -> None: ...
    def Dispose(self) -> None: ...


class ElectricalLoadClassification(Element):
    @property
    def DemandFactorId(self) -> ElementId: ...
    @DemandFactorId.setter
    def DemandFactorId(self, elemId: ElementId) -> None: ...
    @property
    def SpaceLoadClass(self) -> ElectricalLoadClassificationSpace: ...
    @SpaceLoadClass.setter
    def SpaceLoadClass(self, spaceLoadClass: ElectricalLoadClassificationSpace) -> None: ...
    @property
    def Motor(self) -> bool: ...
    @property
    def LoadSummaryDemandFactorLabel(self) -> str: ...
    @LoadSummaryDemandFactorLabel.setter
    def LoadSummaryDemandFactorLabel(self, loadSummaryDemandFactorLabel: str) -> None: ...
    @property
    def PanelConnectedLabel(self) -> str: ...
    @PanelConnectedLabel.setter
    def PanelConnectedLabel(self, panelConnectedLabel: str) -> None: ...
    @property
    def PanelEstimatedLabel(self) -> str: ...
    @PanelEstimatedLabel.setter
    def PanelEstimatedLabel(self, panelEstimatedLabel: str) -> None: ...
    @property
    def PanelConnectedCurrentLabel(self) -> str: ...
    @PanelConnectedCurrentLabel.setter
    def PanelConnectedCurrentLabel(self, panelConnectedCurrentLabel: str) -> None: ...
    @property
    def PanelEstimatedCurrentLabel(self) -> str: ...
    @PanelEstimatedCurrentLabel.setter
    def PanelEstimatedCurrentLabel(self, panelEstimatedCurrentLabel: str) -> None: ...
    @property
    def ActualElectricalLoadLabel(self) -> str: ...
    @ActualElectricalLoadLabel.setter
    def ActualElectricalLoadLabel(self, actualElectricalLoadLabel: str) -> None: ...
    @property
    def Abbreviation(self) -> str: ...
    @Abbreviation.setter
    def Abbreviation(self, abbreviation: str) -> None: ...
    def Create(ADoc: Document, strName: str) -> ElectricalLoadClassification: ...


class ElectricalDemandFactorRule:
    Constant = 0
    QuantityTable = 1
    LoadTable = 2
    QuantityTablePerPortion = 3
    LoadTablePerPortion = 4


class ElectricalLoadClassificationData:
    Name = 0
    SpaceLoadClass = 1
    DemandFactor = 2
    LoadSummaryDemandFactorLabel = 3
    PanelConnectedLabel = 4
    PanelEstimatedLabel = 5
    PanelConnectedCurrentLabel = 6
    PanelEstimatedCurrentLabel = 7
    ActualElecLoadNameLabel = 8
    Abbreviation = 9


class ElectricalLoadClassificationSpace:
    #None = 0
    Lighting = 1
    Power = 2


class PanelScheduleData(TableData):
    @property
    def BorderAroundSections(self) -> ElementId: ...
    @property
    def BorderAroundSchedule(self) -> ElementId: ...
    @property
    def ScheduleType(self) -> PanelScheduleType: ...
    @property
    def PanelConfiguration(self) -> PanelConfiguration: ...
    @property
    def PhaseLoadType(self) -> PanelSchedulePhaseLoadType: ...
    @property
    def NumberOfSlots(self) -> int: ...
    @property
    def IsHeaderSectionHidden(self) -> bool: ...
    @property
    def IsSummarySectionHidden(self) -> bool: ...
    @property
    def IsFooterSectionHidden(self) -> bool: ...
    @property
    def IsThirdPhaseHidden(self) -> bool: ...
    @IsThirdPhaseHidden.setter
    def IsThirdPhaseHidden(self, isThirdPhaseHidden: bool) -> None: ...
    @property
    def SummaryShowsOnlyConnectedLoads(self) -> bool: ...
    @SummaryShowsOnlyConnectedLoads.setter
    def SummaryShowsOnlyConnectedLoads(self, summaryShowsOnlyConnectedLoads: bool) -> None: ...
    @property
    def SummaryShowsGroups(self) -> bool: ...
    @SummaryShowsGroups.setter
    def SummaryShowsGroups(self, summaryShowsGroups: bool) -> None: ...
    @property
    def SummaryShowsVerticalHeaders(self) -> bool: ...
    @property
    def BodyShowsVerticalHeaders(self) -> bool: ...
    @property
    def IsPanelSinglePhase(self) -> bool: ...
    @IsPanelSinglePhase.setter
    def IsPanelSinglePhase(self, isPanelSinglePhase: bool) -> None: ...
    @property
    def ShowCircuitNumberOnOneRowForMultiphaseCircuits(self) -> bool: ...
    @ShowCircuitNumberOnOneRowForMultiphaseCircuits.setter
    def ShowCircuitNumberOnOneRowForMultiphaseCircuits(self, showCircuitNumberOnOneRowForMultiphaseCircuits: bool) -> None: ...
    @property
    def ShowMultipleRowsForMultiphaseCircuits(self) -> bool: ...
    @ShowMultipleRowsForMultiphaseCircuits.setter
    def ShowMultipleRowsForMultiphaseCircuits(self, showMultipleRowsForMultiphaseCircuits: bool) -> None: ...
    @property
    def ShowSlotFromDeviceInsteadOfTemplate(self) -> bool: ...
    @ShowSlotFromDeviceInsteadOfTemplate.setter
    def ShowSlotFromDeviceInsteadOfTemplate(self, showSlotFromDeviceInsteadOfTemplate: bool) -> None: ...
    @property
    def PhasesAsCurrents(self) -> bool: ...
    @property
    def IsUnusedPhaseHidden(self) -> bool: ...
    @IsUnusedPhaseHidden.setter
    def IsUnusedPhaseHidden(self, isUnusedPhaseHidden: bool) -> None: ...
    def IsSymmetric(self) -> bool: ...
    def UpdateIsSectionHidden(self, sectionType: SectionType, bHide: bool) -> None: ...
    def UpdateCircuitTableForInstance(self, pPanel: FamilyInstance) -> None: ...
    def UpdateCircuitTableForTemplate(self, newType: PanelSchedulePhaseLoadType, nNumSlots: int, bPhasesAsCurrents: bool) -> None: ...
    def UpdateLoadSummary(self) -> None: ...
    def UpdateVerticalHeadersInSection(self, sectionType: SectionType, bVertical: bool) -> None: ...
    def GetNumberOfCircuitRows(self) -> int: ...
    def GetLoadClassifications(self) -> List[ElementId]: ...
    def SetLoadClassifications(self, loadClassificaions: List[ElementId]) -> None: ...
    def RemoveLoadClassification(self, nIndex: int) -> None: ...
    def AddLoadClassification(self, loadClassficationId: ElementId) -> bool: ...
    def SetBorderAroundSections(self, borderId: ElementId) -> None: ...
    def SetBorderAroundSchedule(self, borderId: ElementId) -> None: ...


class PanelScheduleSheetInstance(Element):
    @property
    def Origin(self) -> XYZ: ...
    @Origin.setter
    def Origin(self, origin: XYZ) -> None: ...
    @property
    def ScheduleId(self) -> ElementId: ...
    @ScheduleId.setter
    def ScheduleId(self, scheduleId: ElementId) -> None: ...
    def Create(ADoc: Document, scheduleId: ElementId, DBView: View) -> PanelScheduleSheetInstance: ...
    def GetSchedule(self) -> PanelScheduleView: ...
    def SplitSegment(self, iSeg: int) -> bool: ...


class PanelScheduleView(TableView):
    @overload
    def CreateInstanceView(ADoc: Document, templateId: ElementId, panelId: ElementId) -> PanelScheduleView: ...
    @overload
    def CreateInstanceView(ADoc: Document, panelId: ElementId) -> PanelScheduleView: ...
    def GenerateInstanceFromTemplate(self, templateId: ElementId) -> None: ...
    def IsPanelScheduleTemplate(self) -> bool: ...
    def GetTableData(self) -> PanelScheduleData: ...
    def GetSectionData(self, sectionType: SectionType) -> TableSectionData: ...
    def GetTemplate(self) -> ElementId: ...
    def GetPanel(self) -> ElementId: ...
    def GetParamValue(self, sectionType: SectionType, nRow: int, nCol: int) -> str: ...
    def SetParamValue(self, sectionType: SectionType, nRow: int, nCol: int, sValue: str) -> bool: ...
    def GetLoadClassificationParamValue(self, parameterId: ElementId, nRow: int, nCol: int) -> str: ...
    def GetLoadClassificationName(self, nRow: int, nCol: int) -> str: ...
    def GetLoadClassificationDemandLoad(self, nRow: int, nCol: int) -> str: ...
    def GetLoadClassificationConnectedLoad(self, nRow: int, nCol: int) -> str: ...
    def GetLoadClassificationDemandCurrent(self, nRow: int, nCol: int) -> str: ...
    def GetLoadClassificationConnectedCurrent(self, nRow: int, nCol: int) -> str: ...
    def GetLoadClassificationDemandFactor(self, nRow: int, nCol: int) -> str: ...
    def GetLoadClassificationId(self, nRow: int) -> ElementId: ...
    def GetApparentPhaseValue(self, circuitId: ElementId, apparentLoadParam: ElementId) -> float: ...
    def GetCircuitByCell(self, nRow: int, nCol: int) -> ElectricalSystem: ...
    def GetCircuitIdByCell(self, nRow: int, nCol: int) -> ElementId: ...
    def GetSlotNumberByCell(self, nRow: int, nCol: int) -> int: ...
    def GetCellsBySlotNumber(self, nSlotNumber: int) -> Tuple[List[int], List[int]]: ...
    def SetSpareLoadValue(self, row: int, column: int, idLoadParameter: ElementId, value: float) -> None: ...
    def GetSpareLoadValue(self, row: int, column: int, idLoadParameter: ElementId) -> float: ...
    def SetSpareCurrentValue(self, row: int, column: int, idCurrentParameter: ElementId, value: float) -> None: ...
    def GetSpareCurrentValue(self, row: int, column: int, idCurrentParameter: ElementId) -> float: ...
    def IsCellInPhaseLoads(self, nRow: int, nCol: int) -> bool: ...
    def IsRowInCircuitTable(self, nRow: int) -> bool: ...
    def IsColumnInLoadSummary(self, nCol: int) -> bool: ...
    def GetCombinedParamValue(self, sectionType: SectionType, nRow: int, nCol: int) -> str: ...
    def IsSlotLocked(self, nRow: int, nCol: int) -> bool: ...
    def IsSlotGrouped(self, nRow: int, nCol: int) -> int: ...
    def IsSpare(self, nRow: int, nCol: int) -> bool: ...
    def IsSpace(self, nRow: int, nCol: int) -> bool: ...
    def AddSpace(self, nRow: int, nCol: int) -> None: ...
    def AddSpare(self, nRow: int, nCol: int) -> None: ...
    def RemoveSpace(self, nRow: int, nCol: int) -> None: ...
    def RemoveSpare(self, nRow: int, nCol: int) -> None: ...
    def CanMoveSlotTo(self, nMovingRow: int, nMovingCol: int, nToRow: int, nToCol: int) -> bool: ...
    def MoveSlotTo(self, nMovingRow: int, nMovingCol: int, nToRow: int, nToCol: int) -> None: ...
    def RenumberIndexes(self) -> None: ...
    def SwitchPhases(self, nRow: int, nCol: int) -> None: ...


class PanelScheduleTemplate(Element):
    @property
    def IsBranchPanelSchedule(self) -> bool: ...
    @property
    def IsDataPanelSchedule(self) -> bool: ...
    @property
    def IsSwitchboardSchedule(self) -> bool: ...
    @property
    def IsDefault(self) -> bool: ...
    def Create(document: Document, type: PanelScheduleType, config: PanelConfiguration, strName: str) -> PanelScheduleTemplate: ...
    def CopyFrom(self, OtherADoc: Document, otherElem: PanelScheduleTemplate) -> None: ...
    def GetPanelScheduleType(self) -> PanelScheduleType: ...
    def SetTableData(self, Data: PanelScheduleData) -> None: ...
    def GetTableData(self) -> PanelScheduleData: ...
    def GetSectionData(self, sectionType: SectionType) -> TableSectionData: ...
    @overload
    def IsValidType(panelScheduleType: PanelScheduleType) -> bool: ...
    def HasSameType(self, otherTemplate: PanelScheduleTemplate) -> bool: ...
    def IsValidPanelConfiguration(scheduleType: PanelScheduleType, configuration: PanelConfiguration) -> bool: ...


class PanelConfiguration:
    OneColumn = 0
    TwoColumnsCircuitsAcross = 1
    TwoColumnsCircuitsDown = 2


class PanelScheduleType:
    Branch = 0
    Switchboard = 1
    Data = 2
    Unknown = -1



class StatusBarDrawItemEventArgs(DrawItemEventArgs):
 """
 Provides data for the System.Windows.Forms.StatusBar.DrawItem event.

 

 StatusBarDrawItemEventArgs(g: Graphics,font: Font,r: Rectangle,itemId: int,itemState: DrawItemState,panel: StatusBarPanel)

 StatusBarDrawItemEventArgs(g: Graphics,font: Font,r: Rectangle,itemId: int,itemState: DrawItemState,panel: StatusBarPanel,foreColor: Color,backColor: Color)
 """
 @staticmethod
 def __new__(self,g,font,r,itemId,itemState,panel,foreColor=None,backColor=None):
  """
  __new__(cls: type,g: Graphics,font: Font,r: Rectangle,itemId: int,itemState: DrawItemState,panel: StatusBarPanel)

  __new__(cls: type,g: Graphics,font: Font,r: Rectangle,itemId: int,itemState: DrawItemState,panel: StatusBarPanel,foreColor: Color,backColor: Color)
  """
  pass
 Panel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.StatusBarPanel to draw.



Get: Panel(self: StatusBarDrawItemEventArgs) -> StatusBarPanel



"""


